---
title: Urubu 0.3 released
layout: page 
date: 2014-02-27
---

This release adds markdown support for front-matter attributes.
[Read more&nbsp;&raquo;](/manual/structure.html#markdown-in-attributes)
